pub fn load_json<T>(path: impl AsRef<Path>) -> Result<T, FaucetError>where
T: DeserializeOwned,Expand description
Load a config struct from a JSON file.
The file contents are read and deserialized into T.
pub fn load_json<T>(path: impl AsRef<Path>) -> Result<T, FaucetError>where
T: DeserializeOwned,Load a config struct from a JSON file.
The file contents are read and deserialized into T.