Task notification.
Structs
- Context
- The context of an asynchronous task.
- RawWaker
- A
RawWakerallows the implementor of a task executor to create aWakeror aLocalWakerwhich provides customized wakeup behavior. - RawWakerV
Table - A virtual function pointer table (vtable) that specifies the behavior
of a
RawWaker. - Waker
- A
Wakeris a handle for waking up a task by notifying its executor that it is ready to be run.
Enums
- Poll
- Indicates whether a value is available or if the current task has been scheduled to receive a wakeup instead.