pub enum ReplicationEvent {
KeepAlive {
wal_end: Lsn,
reply_requested: bool,
server_time_micros: i64,
},
Begin {
final_lsn: Lsn,
xid: u32,
commit_time_micros: i64,
},
XLogData {
wal_start: Lsn,
wal_end: Lsn,
server_time_micros: i64,
data: Bytes,
},
Commit {
lsn: Lsn,
end_lsn: Lsn,
commit_time_micros: i64,
},
Message {
transactional: bool,
lsn: Lsn,
prefix: String,
content: Bytes,
},
StoppedAt {
reached: Lsn,
},
}Available on crate features
source-postgres-cdc and source-rest only.Expand description
Events emitted by the replication worker.
Variants
KeepAlive
Server heartbeat message.
Fields
Begin
Start of a transaction (pgoutput Begin message).
XLogData
WAL data containing transaction changes.
Fields
Commit
End of a transaction (pgoutput Commit message).
Message
Logical decoding message emitted via pg_logical_emit_message().
Transactional messages are delivered only after the enclosing transaction commits. Non-transactional messages are delivered immediately.
Fields
StoppedAt
Emitted when stop_at_lsn has been reached.
After this event, no more events will be emitted and the replication stream will be closed.