Module redis

Module redis 

Available on crate features source-redis and source-rest only.

Modules

config
Redis source configuration.
stream
Redis source stream executor.

Structs

RedisSource
A configured Redis source that reads records from Redis data structures.
RedisSourceConfig
Configuration for the Redis source connector.

Enums

FaucetError
All possible errors returned by faucet-stream.
RedisSourceType
The type of Redis data structure to read from.

Traits

A source fetches records from an external system.