Available on crate feature
source-rest only.Expand description
Authentication strategies for REST APIs.
Modules
- api_key
- API key header authentication.
- basic
- HTTP Basic authentication.
- bearer
- Bearer token authentication.
- custom
- Custom header-based authentication.
- oauth2
- OAuth2 client credentials flow with token caching.
- token_
endpoint - Generic token-endpoint authentication with caching.
Structs
- Response
Validator - Optional callback to decide whether the token endpoint response is successful.
Enums
- Auth
- Supported authentication methods.
Functions
- fetch_
oauth2_ token - Fetch an OAuth2 token using the client credentials grant.
- fetch_
token_ from_ endpoint - Fetch a token from the given endpoint and extract it using JSONPath.