max_value

Function max_value 

pub fn max_value(a: Value, b: Value) -> Value
Available on crate feature source-rest only.
Return the larger of two replication values using the same ordering as max_replication_value (string lexicographic, numeric for numbers, falling back to a on type mismatch).