Module spanner

Module spanner 

Available on crate features source-rest and source-spanner only.

Structs

ShardConfig
Primary-key range sharding settings for the Spanner source (clustered Mode B execution).
SpannerConnection
Connection block shared by the Spanner source and sink configs (flattened into each connector config via #[serde(flatten)]).
SpannerSource
Google Cloud Spanner query source.
SpannerSourceConfig
Configuration for SpannerSource.

Enums

SpannerCredentials
Credentials used to authenticate against Cloud Spanner.
SpannerReplication
How the source replicates rows across runs.