pub struct WebhookSource { /* private fields */ }Available on crate features
source-rest and source-webhook only.Expand description
A webhook receiver source that starts a temporary HTTP server and collects incoming POST payloads as records.
Implementations
Sourceimpl WebhookSource
impl WebhookSource
Sourcepub fn new(config: WebhookSourceConfig) -> WebhookSource
pub fn new(config: WebhookSourceConfig) -> WebhookSource
Create a new webhook source from the given configuration.