Available on crate feature
state-postgres only.Modules
- store
- PostgreSQL-backed
StateStore.
Structs
- Postgres
State Store - A
StateStorethat persists each entry as a row in a single Postgres table.
state-postgres only.StateStore.StateStore that persists each entry as a row in a single Postgres
table.