apply_all

Function apply_all 

pub fn apply_all(
    record: Value,
    transforms: &[CompiledTransform],
) -> Result<Value, FaucetError>
Apply a slice of pre-compiled transforms to a record, in order.

Returns FaucetError::Transform if a transform would silently lose data — currently when flatten, keys_case, or spell_symbols collapse two distinct fields to the same key (#78/#28).