Available on crate features
sink-pubsub or source-pubsub only.Expand description
Shared Google Cloud Pub/Sub types (credentials enum, connection block, client builder), re-exported when either Pub/Sub connector is enabled.
Structs
- Pubsub
Connection - Connection settings shared by the Pub/Sub source and sink. Flattened into
each connector config via
#[serde(flatten)], soproject_id/endpoint/emulator_host/credentialsappear at the config top level. - Pubsub
Message - A message that is published by publishers and consumed by subscribers. The message must contain either a non-empty data field or at least one attribute. Note that client libraries represent this object differently depending on the language. See the corresponding client library documentation for more information. See [quotas and limits] (https://cloud.google.com/pubsub/quotas) for more information about message limits.
Enums
- Pubsub
Credentials - How to authenticate with Google Cloud Pub/Sub.
Functions
- build_
client - Build a Pub/Sub
Clientfrom aPubsubConnection.