Module replication

Module replication 

Incremental replication support.

Enums

ReplicationMethod
Determines how records are replicated from the source.

Functions

filter_incremental
Filter records to only those where record[key] > start.
max_replication_value
Return the maximum value of record[key] across all records, if any.
max_value
Return the larger of two replication values using the same ordering as max_replication_value (string lexicographic, numeric for numbers, falling back to a on type mismatch).