Available on crate features
source-delta and source-rest only.Structs
- Delta
Connection - Location + credentials for a Delta table. Flattened (
#[serde(flatten)]) into both the source and sink config so the same three keys appear at the connector-config top level. - Delta
Source - A source that reads an Apache Delta Lake table into JSON records.
- Delta
Source Config - Configuration for the Delta Lake source connector.
Enums
- Delta
Credentials - Object-store credentials for reading/writing a Delta table.