Available on crate features
source-grpc and source-rest only.Modules
Structs
- Grpc
Stream - A configured gRPC source that uses protobuf reflection to call any gRPC method and return JSON records.
- Grpc
Stream Config - Configuration for the gRPC source.
- Metadata
Entry - A single piece of gRPC request metadata.
Enums
- Auth
Spec - A connector’s
auth:field: either an inline auth definitionA(the{ type, config }shape), or a{ ref: <name> }reference to a shared provider defined in the top-levelauth:catalog. - Faucet
Error - All possible errors returned by faucet-stream.
- Grpc
Auth - Authentication for gRPC endpoints.
- RpcKind
- Kind of gRPC RPC to invoke.
Traits
- Source
- A source fetches records from an external system.
Type Aliases
- Shared
Auth Provider - A shared
AuthProviderhandle. Cloning it shares the one live provider (and its single token cache) across connectors.