Available on crate features
source-redis and source-rest only.Modules
Structs
- Redis
Source - A configured Redis source that reads records from Redis data structures.
- Redis
Source Config - Configuration for the Redis source connector.
Enums
- Faucet
Error - All possible errors returned by faucet-stream.
- Redis
Source Type - The type of Redis data structure to read from.
Traits
- Source
- A source fetches records from an external system.