Module auth

Module auth 

Available on crate feature source-rest only.
Authentication strategies for REST APIs.

Modules

api_key
API key header authentication.
basic
HTTP Basic authentication.
bearer
Bearer token authentication.
custom
Custom header-based authentication.
oauth2
OAuth2 client credentials flow with token caching.
token_endpoint
Generic token-endpoint authentication with caching.

Structs

ResponseValidator
Optional callback to decide whether the token endpoint response is successful.

Enums

Auth
Supported authentication methods.

Functions

fetch_oauth2_token
Fetch an OAuth2 token using the client credentials grant.
fetch_token_from_endpoint
Fetch a token from the given endpoint and extract it using JSONPath.