pub struct RestStreamConfig {Show 25 fields
pub base_url: String,
pub path: String,
pub method: Method,
pub auth: AuthSpec<Auth>,
pub headers: HeaderMap,
pub query_params: HashMap<String, String>,
pub body: Option<Value>,
pub pagination: PaginationStyle,
pub records_path: Option<String>,
pub max_pages: Option<usize>,
pub request_delay: Option<Duration>,
pub timeout: Option<Duration>,
pub max_retries: u32,
pub retry_backoff: Duration,
pub tolerated_http_errors: Vec<u16>,
pub replication_method: ReplicationMethod,
pub replication_key: Option<String>,
pub start_replication_value: Option<Value>,
pub state_key: Option<String>,
pub name: Option<String>,
pub primary_keys: Vec<String>,
pub schema: Option<Value>,
pub schema_sample_size: usize,
pub partitions: Vec<HashMap<String, Value>>,
pub partition_concurrency: Option<usize>,
}source-rest only.Expand description
Configuration for a RestStream.
Fields
base_url: Stringpath: StringURL path, relative to base_url. May contain {key} placeholders that
are substituted per-partition (e.g. "/orgs/{org_id}/users").
method: Methodauth: AuthSpec<Auth>Authentication: either inline ({ type, config }) or a { ref: <name> }
pointer to a shared provider in the CLI’s top-level auth: catalog.
headers: HeaderMapquery_params: HashMap<String, String>body: Option<Value>pagination: PaginationStylerecords_path: Option<String>max_pages: Option<usize>request_delay: Option<Duration>timeout: Option<Duration>max_retries: u32retry_backoff: Durationtolerated_http_errors: Vec<u16>HTTP status codes that should not cause an error. Responses with these codes are treated as empty pages (no records, no further pages).
replication_method: ReplicationMethodreplication_key: Option<String>Field name (not a JSONPath) used for incremental replication bookmarking.
start_replication_value: Option<Value>Bookmark value: records where record[replication_key] <= start_replication_value
are filtered out when replication_method is Incremental.
state_key: Option<String>Opt-in identifier used by Pipeline::with_state_store
to persist this stream’s bookmark across runs. When set, the pipeline
will load any previously-stored bookmark before fetching and write the
new bookmark only after the sink confirms the batch.
Keys must satisfy faucet_core::state::validate_state_key.
name: Option<String>Human-readable stream name (used in logging and Singer SCHEMA messages).
primary_keys: Vec<String>Field names that uniquely identify a record (Singer key_properties).
schema: Option<Value>JSON Schema describing the structure of each record.
schema_sample_size: usizeMaximum number of records to sample when inferring the schema via
crate::stream::RestStream::infer_schema. 0 means sample all
available records (up to max_pages). Defaults to 100.
partitions: Vec<HashMap<String, Value>>Each entry is a context map whose values are substituted into path
placeholders. The stream is executed once per partition and results are
concatenated. Empty means run once with no substitution.
partition_concurrency: Option<usize>Maximum number of partitions to fetch concurrently.
None means sequential processing (backward compatible default).
Implementations
Sourceimpl RestStreamConfig
impl RestStreamConfig
pub fn new(base_url: &str, path: &str) -> RestStreamConfig
pub fn method(self, m: Method) -> RestStreamConfig
pub fn auth(self, a: Auth) -> RestStreamConfig
pub fn header(self, k: &str, v: &str) -> RestStreamConfig
pub fn query(self, k: &str, v: &str) -> RestStreamConfig
pub fn body(self, b: Value) -> RestStreamConfig
pub fn pagination(self, p: PaginationStyle) -> RestStreamConfig
pub fn records_path(self, p: &str) -> RestStreamConfig
pub fn max_pages(self, n: usize) -> RestStreamConfig
pub fn request_delay(self, d: Duration) -> RestStreamConfig
pub fn timeout(self, d: Duration) -> RestStreamConfig
pub fn max_retries(self, n: u32) -> RestStreamConfig
pub fn retry_backoff(self, d: Duration) -> RestStreamConfig
Sourcepub fn tolerate_http_error(self, status: u16) -> RestStreamConfig
pub fn tolerate_http_error(self, status: u16) -> RestStreamConfig
HTTP status codes that should be silently ignored (treated as empty pages).
pub fn replication_method(self, m: ReplicationMethod) -> RestStreamConfig
Sourcepub fn replication_key(self, key: &str) -> RestStreamConfig
pub fn replication_key(self, key: &str) -> RestStreamConfig
Field name (not JSONPath) used as the incremental replication bookmark.
Sourcepub fn start_replication_value(self, v: Value) -> RestStreamConfig
pub fn start_replication_value(self, v: Value) -> RestStreamConfig
Bookmark start value: records at or before this value are filtered out
when using ReplicationMethod::Incremental.
Sourcepub fn state_key(self, key: &str) -> RestStreamConfig
pub fn state_key(self, key: &str) -> RestStreamConfig
Opt the stream into resumable runs by giving it a stable state key.
When this is set and the Pipeline is
configured with a state store, the previously persisted bookmark is
applied to the stream before fetching.
Sourcepub fn name(self, n: &str) -> RestStreamConfig
pub fn name(self, n: &str) -> RestStreamConfig
Human-readable stream name.
Sourcepub fn primary_keys(self, keys: Vec<String>) -> RestStreamConfig
pub fn primary_keys(self, keys: Vec<String>) -> RestStreamConfig
Field names that uniquely identify a record (Singer key_properties).
Sourcepub fn schema(self, s: Value) -> RestStreamConfig
pub fn schema(self, s: Value) -> RestStreamConfig
JSON Schema for the stream’s records.
Sourcepub fn schema_sample_size(self, n: usize) -> RestStreamConfig
pub fn schema_sample_size(self, n: usize) -> RestStreamConfig
Maximum records to sample for schema inference (0 = unlimited).
Sourcepub fn add_partition(self, ctx: HashMap<String, Value>) -> RestStreamConfig
pub fn add_partition(self, ctx: HashMap<String, Value>) -> RestStreamConfig
Add a partition context. The stream will execute once for each partition,
substituting {key} placeholders in path with values from the context.
Sourcepub fn partition_concurrency(
self,
concurrency: Option<usize>,
) -> RestStreamConfig
pub fn partition_concurrency( self, concurrency: Option<usize>, ) -> RestStreamConfig
Set the maximum number of partitions to fetch concurrently.
None (default) means sequential processing.