Available on crate feature
source-rest only.Expand description
Incremental replication support.
Enums
- Replication
Method - Determines how records are replicated from the source.
Functions
- filter_
incremental - Filter
recordsto only those whererecord[key] > start. - max_
replication_ value - Return the maximum value of
record[key]across all records, if any. - max_
value - Return the larger of two replication values using the same ordering as
max_replication_value(string lexicographic, numeric for numbers, falling back toaon type mismatch).