Available on crate features
source-rest and source-spanner only.Structs
- Shard
Config - Primary-key range sharding settings for the Spanner source (clustered Mode B execution).
- Spanner
Connection - Connection block shared by the Spanner source and sink configs (flattened
into each connector config via
#[serde(flatten)]). - Spanner
Source - Google Cloud Spanner query source.
- Spanner
Source Config - Configuration for
SpannerSource.
Enums
- Spanner
Credentials - Credentials used to authenticate against Cloud Spanner.
- Spanner
Replication - How the source replicates rows across runs.